'use strict';

var integration = require('@backstage/integration');
var webhooksMethods = require('@octokit/webhooks-methods');
var createAppIdResolver = require('../util/createAppIdResolver.cjs.js');

function createGithubSignatureValidator(config, octokitProvider) {
  const integrations = integration.ScmIntegrations.fromConfig(config);
  const githubAppSecrets = /* @__PURE__ */ new Map();
  for (const integration of integrations.github.list()) {
    for (const { appId, webhookSecret } of integration.config.apps ?? []) {
      if (appId && webhookSecret) {
        githubAppSecrets.set(appId, webhookSecret);
      }
    }
  }
  const genericSecret = config.getOptionalString(
    "events.modules.github.webhookSecret"
  );
  if (!genericSecret && githubAppSecrets.size === 0) {
    return void 0;
  }
  const appIdResolver = createAppIdResolver.createAppIdResolver(octokitProvider);
  return async (request, context) => {
    const signature = request.headers["x-hub-signature-256"];
    if (signature) {
      const body = request.raw.body.toString(request.raw.encoding);
      if (githubAppSecrets.size) {
        const appId = await appIdResolver(request);
        if (appId && githubAppSecrets.has(appId)) {
          if (await webhooksMethods.verify(githubAppSecrets.get(appId), body, signature)) {
            return;
          }
        }
      }
      if (genericSecret) {
        if (await webhooksMethods.verify(genericSecret, body, signature)) {
          return;
        }
      }
    }
    context.reject({
      status: 403,
      payload: { message: "invalid signature" }
    });
  };
}

exports.createGithubSignatureValidator = createGithubSignatureValidator;
//# sourceMappingURL=createGithubSignatureValidator.cjs.js.map
